/* 
 * Blinky - a GTK network usage monitor
 *
 * Copyright (C) 2002, Benjamin Miller <bmiller@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include <fcntl.h>
#include <gtk/gtk.h>
#include "blinky.h"


/* TODO:
   timer calls update_all (gpointer data)
   update_all calls get_usage_all (void)
   get_usage_all - current get_usage without graphics updates
   		 - possibly calls parse function for each if
		 - OS specific (/proc/net/dev vs. kstat)
   update_all calls ifa_draw for all if's that have changed
   each if's eventbox calls ifa_draw on "expose_event" signal
   to get stats for one if, use tx_cur and rx_cur from struct
*/


/* Global variables */
GtkWidget *mainbox;
GtkTooltips *tips;
GSList *ifs; /* list of IFA structs */
blinky_opts *options;


int
main (int argc, char **argv)
{
    static guint32 timer;
    GtkWidget *mainwin;

    gtk_init (&argc, &argv);

    mainbox = gtk_vbox_new (FALSE, 5);
    tips = gtk_tooltips_new();

    get_setup (argc, argv);

    mainwin = show_main_window();

    update_all (NULL);
    timer = gtk_timeout_add (options->interval, 
			     update_all, NULL);

    gtk_main();

    return 0;
}


GtkWidget *
show_main_window (void)
{
    GtkWidget *window;

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_signal_connect (GTK_OBJECT(window), "destroy", 
			GTK_SIGNAL_FUNC(quit), NULL);
    gtk_signal_connect (GTK_OBJECT(window), "destroy_event", 
			GTK_SIGNAL_FUNC(quit), NULL);
    gtk_container_set_border_width (GTK_CONTAINER(window), 5);
    gtk_window_set_policy (GTK_WINDOW(window), TRUE, TRUE, TRUE);
    gtk_widget_realize (window);

    gtk_container_add (GTK_CONTAINER(window), mainbox);
    gtk_widget_show (mainbox);

    gtk_widget_show (window);
    return window;
}


void
quit (GtkWidget *w, gpointer dummy)
{
    gtk_main_quit();
}


/*
 * Local variables:
 * c-basic-offset: 4
 * End:
 */
